@@ -35,17 +35,13 @@ def copy_cfg_files(
     exclude_autofix_regex = ""
     if exclude_lint:
         exclude_lint_regex = "(%s)|" % "|".join(
-            [
-                re.escape(exclude_path.strip())
-                for exclude_path in exclude_lint.split(",")
-                if exclude_path and exclude_path.strip()
-            ]
+            [re.escape(exclude_path.strip()) for exclude_path in exclude_lint if exclude_path and exclude_path.strip()]
         )
     if exclude_autofix:
         exclude_autofix_regex = "(%s)|" % "|".join(
             [
                 re.escape(exclude_path.strip())
-                for exclude_path in exclude_autofix.split(",")
+                for exclude_path in exclude_autofix
                 if exclude_path and exclude_path.strip()
             ]
         )
@@ -74,7 +70,7 @@ def copy_cfg_files(
                         _logger.info("Applying EXCLUDE_AUTOFIX=%s to %s", exclude_autofix, dst)
                         line += "    %s\n" % exclude_autofix_regex
                 if disable_pylint_checks and fname.startswith(".pre-commit-config") and "--disable=R0000" in line:
-                    line = line.replace("R0000", disable_pylint_checks)
+                    line = line.replace("R0000", ','.join(disable_pylint_checks))
                 fdst.write(line)
 
 
@@ -103,25 +99,15 @@ def subprocess_call(command, *args, **kwargs):
     return subprocess.call(command, *args, **kwargs)
 
 
-def main(argv=None, do_exit=True):
+# There are a lot of if validations in this method. It is expected for now.
+# pylint: disable=too-complex
+def main(include_lint, overwrite, exclude_autofix, exclude_lint, disable_pylint_checks, autofix, config, do_exit=True):
     repo_dirname = get_repo()
     cwd = os.path.abspath(os.path.realpath(os.getcwd()))
 
     envdict = envfile2envdict(repo_dirname)
     os.environ.update(envdict)
 
-    # Get the configuration files but you can use custom ones so set "0"
-    overwrite = os.environ.get("PRECOMMIT_OVERWRITE_CONFIG_FILES", "1") == "1"
-    # Exclude paths to lint
-    exclude_lint = os.environ.get("EXCLUDE_LINT", "")
-    # Exclude paths to fix
-    exclude_autofix = os.environ.get("EXCLUDE_AUTOFIX", "")
-    # Disable pylint checks
-    disable_pylint_checks = os.environ.get("DISABLE_PYLINT_CHECKS", "")
-    # Enable .pre-commit-config-autofix.yaml configuration file
-    enable_auto_fix = os.environ.get("PRECOMMIT_AUTOFIX", "") == "1"
-    include_lint = os.environ.get('INCLUDE_LINT')
-
     root_dir = os.path.abspath(os.path.dirname(__file__))
 
     precommit_config_dir = os.path.join(root_dir, "cfg")
@@ -134,15 +120,19 @@ def main(argv=None, do_exit=True):
         disable_pylint_checks,
         exclude_autofix,
     )
+    if autofix:
+        config = ("mandatory", "optional", "fix")
 
     _logger.info("Installing pre-commit hooks")
     cmd = ["pre-commit", "install-hooks", "--color=always"]
     pre_commit_cfg_mandatory = os.path.join(repo_dirname, ".pre-commit-config.yaml")
     pre_commit_cfg_optional = os.path.join(repo_dirname, ".pre-commit-config-optional.yaml")
     pre_commit_cfg_autofix = os.path.join(repo_dirname, ".pre-commit-config-autofix.yaml")
-    subprocess_call(cmd + ["-c", pre_commit_cfg_mandatory])
-    subprocess_call(cmd + ["-c", pre_commit_cfg_optional])
-    if enable_auto_fix:
+    if "mandatory" in config or 'all' in config:
+        subprocess_call(cmd + ["-c", pre_commit_cfg_mandatory])
+    if "optional" in config or 'all' in config:
+        subprocess_call(cmd + ["-c", pre_commit_cfg_optional])
+    if "fix" in config or 'all' in config:
         subprocess_call(cmd + ["-c", pre_commit_cfg_autofix])
 
     status = 0
@@ -156,16 +146,15 @@ def main(argv=None, do_exit=True):
         cmd.extend(["--files"] + files)
     elif include_lint:
         _logger.info("Running only for INCLUDE_LINT=%s", include_lint)
-        included_paths = map(str.strip, include_lint.strip().split(','))
         included_files = []
-        for included_path in included_paths:
-            included_files += get_files(included_path)
+        for included_path in include_lint:
+            included_files += get_files(included_path) or (included_path,)
         cmd.extend(["--files"] + included_files)
     else:
         cmd.append("--all")
     all_status = {}
 
-    if enable_auto_fix:
+    if "fix" in config or 'all' in config:
         _logger.info("%s AUTOFIX CHECKS %s", "-" * 25, "-" * 25)
         _logger.info("Running autofix checks (affect status build but you can autofix them locally)")
         autofix_status = subprocess_call(cmd + ["-c", pre_commit_cfg_autofix])
@@ -182,36 +171,38 @@ def main(argv=None, do_exit=True):
             all_status[test_name]['status_msg'] = "Passed"
         _logger.info("-" * 66)
 
-    _logger.info("%s MANDATORY CHECKS %s", "*" * 25, "*" * 25)
-    _logger.info("Running mandatory checks (affect status build)")
-    mandatory_status = subprocess_call(cmd + ["-c", pre_commit_cfg_mandatory])
-    status += mandatory_status
-    test_name = 'Mandatory checks'
-    all_status[test_name] = {'status': mandatory_status}
-    if status != 0:
-        _logger.error("%s failed", test_name)
-        all_status[test_name]['level'] = logging.ERROR
-        all_status[test_name]['status_msg'] = "Failed"
-    else:
-        _logger.info("%s passed!", test_name)
-        all_status[test_name]['level'] = logging.INFO
-        all_status[test_name]['status_msg'] = "Passed"
+    if "mandatory" in config or 'all' in config:
+        _logger.info("%s MANDATORY CHECKS %s", "*" * 25, "*" * 25)
+        _logger.info("Running mandatory checks (affect status build)")
+        mandatory_status = subprocess_call(cmd + ["-c", pre_commit_cfg_mandatory])
+        status += mandatory_status
+        test_name = 'Mandatory checks'
+        all_status[test_name] = {'status': mandatory_status}
+        if status != 0:
+            _logger.error("%s failed", test_name)
+            all_status[test_name]['level'] = logging.ERROR
+            all_status[test_name]['status_msg'] = "Failed"
+        else:
+            _logger.info("%s passed!", test_name)
+            all_status[test_name]['level'] = logging.INFO
+            all_status[test_name]['status_msg'] = "Passed"
 
-    _logger.info("*" * 68)
-    _logger.info("%s OPTIONAL CHECKS %s", "~" * 25, "~" * 25)
-    _logger.info("Running optional checks (does not affect status build)")
-    status_optional = subprocess_call(cmd + ["-c", os.path.join(repo_dirname, pre_commit_cfg_optional)])
-    test_name = 'Optional checks'
-    all_status[test_name] = {'status': status_optional}
-    if status_optional != 0:
-        _logger.warning("Optional checks failed")
-        all_status[test_name]['level'] = logging.WARNING
-        all_status[test_name]['status_msg'] = "Failed"
-    else:
-        _logger.info("Optional checks passed!")
-        all_status[test_name]['level'] = logging.INFO
-        all_status[test_name]['status_msg'] = "Passed"
-    _logger.info("~" * 67)
+    if "optional" in config or 'all' in config:
+        _logger.info("*" * 68)
+        _logger.info("%s OPTIONAL CHECKS %s", "~" * 25, "~" * 25)
+        _logger.info("Running optional checks (does not affect status build)")
+        status_optional = subprocess_call(cmd + ["-c", os.path.join(repo_dirname, pre_commit_cfg_optional)])
+        test_name = 'Optional checks'
+        all_status[test_name] = {'status': status_optional}
+        if status_optional != 0:
+            _logger.warning("Optional checks failed")
+            all_status[test_name]['level'] = logging.WARNING
+            all_status[test_name]['status_msg'] = "Failed"
+        else:
+            _logger.info("Optional checks passed!")
+            all_status[test_name]['level'] = logging.INFO
+            all_status[test_name]['status_msg'] = "Passed"
+        _logger.info("~" * 67)
 
     print_summary(all_status)
     if do_exit:
